#
# spec file for package google-cloud-sdk
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           google-cloud-sdk
Version:        0.9.87
Release:        7.1
Summary:        Tools for Google Cloud Services
License:        Apache-2.0
Group:          System/Management
# Get the filename to download from
# https://dl.google.com/dl/cloudsdk/release/sha1.txt
Url:            https://dl.google.com/dl/cloudsdk/release
Source0:        %{name}-%{version}.tar.bz2
Source1:        setup.py
Patch1:         hidePathMangeling.patch
Patch2:         disableSelfUpdate.patch
Requires:       python
Requires:       python-Jinja2
Requires:       python-MarkupSafe
Requires:       python-SocksiPy
Requires:       python-antlr3_runtime
Requires:       python-argcomplete
Requires:       python-argparse
Requires:       python-docker-py
Requires:       python-enum34
Requires:       python-httplib2          => 0.8
Requires:       python-ipaddr
Requires:       python-oauth2
Requires:       python-oauth2client
Requires:       python-oauth2client-gce
Requires:       python-portpicker
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Requires:       python-python-gflags
Requires:       python-python-mimeparse
Requires:       python-requests
Requires:       python-rsa
Requires:       python-six
Requires:       python-uritemplate
Requires:       python-websocket-client
Requires:       python-yaml
Provides:       gcutils > 1.13.0
Provides:       gsutils > 3.42
Obsoletes:      gcutils <= 1.13.0
Obsoletes:      gsutils <= 3.42
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Google Cloud SDK contains tools and libraries that allow you to create and
manage resources on Google Cloud Platform, including App Engine, Compute
Engine, Cloud Storage, Cloud SQL, and BigQuery.

%prep
%setup -q
%patch1
%patch2

cp %{SOURCE1} %{_builddir}/%{name}-%{version}

%build
python setup.py build

%install
# Leave it to Google to set silly permissions, fix it
find . -name "*.html" | xargs chmod -x 
find . -name "*.json" | xargs chmod -x
find . -name "*_test.py" | xargs chmod +x
find lib/protorpc -name "*.py" | xargs chmod -x
# Remove shebang from files intended for import
find lib/googlecloudsdk/third_party/appengine -type f | xargs grep -l '#!' | xargs sed -i 1d
find lib/protorpc -type f | xargs grep -l '#!' | xargs sed -i 1d
# Install gcloud
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_defaultdocdir}/%{name}
install -d %{buildroot}/%{_mandir}
install -d %{buildroot}/%{_sysconfdir}/bash_completion.d
cp completion.bash.inc %{buildroot}/%{_sysconfdir}/bash_completion.d/gcloud.sh
echo "#!/bin/sh" > %{buildroot}/%{_bindir}/gcloud
echo "python %{python_sitelib}/googlecloudsdk/gcloud/gcloud.py \"\$@\"" >> %{buildroot}/%{_bindir}/gcloud
chmod +x %{buildroot}/%{_bindir}/gcloud

%files
%defattr(-,root,root,-)
%doc LICENSE README RELEASE_NOTES
%dir %{python_sitelib}/google
%dir %{python_sitelib}/googlecloudsdk
%dir %{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info
%{_bindir}/gcloud
%{python_sitelib}/google/*
%{python_sitelib}/googlecloudsdk/*
%{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info/*
%config %{_sysconfdir}/bash_completion.d/gcloud.sh
# built in dependency on fancy_urllib, not available as stand alone code stream
%dir %{python_sitelib}/fancy_urllib
%{python_sitelib}/fancy_urllib/*
# built in dependency on protorpc, not available as stand alone code stream
%dir %{python_sitelib}/protorpc
%{python_sitelib}/protorpc/*

%changelog
* Mon Nov 30 2015 rjschwei@suse.com
- Provide a better message for "components" sub command being disabled
  + Added patch disableSelfUpdate.patch
* Sat Nov 21 2015 rjschwei@suse.com
- Remove patches:
  + gsutil_respectBotoCfgKeyword.patch
  + gsutilHideDeps.patch
  + gcutilHideDeps.patch
  + hideImplicitVersionMgmt.patch
  + gsutil_noVersioCheckOrUpdate.patch
  + gcutilNoInternalVersionCheck.patch
  + bqHideDeps.patch
- Update to version 0.9.87  (bsc#954690)
  [#]## Compute
  * `gcloud alpha compute instances create` now supports --custom-cpu and
  - -custom-memory flags to specify custom machine types.
  [#]## Dataproc
  * Added `gcloud beta dataproc clusters diagnose` command. See
    <https://cloud.google.com/dataproc/support/diagnose-command> for
    more info.
  [#]## Google Container Engine
  * Updated kubectl to version 1.1.1.
  * 0.9.86 (2015/11/11)
  [#]## App Engine
  * Generated node.js Dockerfiles now add the full application context before
    running install hooks.
  * For Google App Engine Node.js runtimes, install requested version of node
    prior to doing an npm install.
  [#]## Compute
  * `gcloud beta compute instances set-machine-type` has been promoted
    from alpha to beta,
  * From 0.9.85 (2015/11/04)
  * `gcloud alpha compute networks create` now requires --mode flag.
  (Backwards incompatible change)
  [#]## App Engine
  * Added the --output-directory option to gen-repo-info-file command.
    This option supersedes --output-file, which is deprecated and will
    be removed in a future release.
  * Improved error message when specified yaml file is not found.
  [#]## Compute
  * Launching `gcloud alpha compute networks subnets`.
  * `gcloud compute alpha instance-templates` and `instances` now support
    subnetworks.
  * New flag --ike-networks in `gcloud alpha compute vpn-tunnels create`.
  * `gcloud compute ssh` now passes through the exit code of the ssh
    command. This fixes issue [#146 ]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=146).
  [#]## Misc. Changes
  * Gracefully handle socket timeouts while checking for Google Compute
    Engine metadata server. This fixes issue [#339]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=339).
  * From 0.9.84 (2015/10/28)
  [#]## App Engine
  * Due to PageSpeed service deprecation, user will receive a warning when
    deploying a new version to App Engine.
  * Implemented fingerprinting support for Java.
  * The gen-config flag now generates only app.yaml for the matching
    runtime by default, you must use the --custom flag to generate an
    app.yaml with a runtime of "custom" and Dockerfile (and other configs).
  [#]## Compute
  * GA support for https load balancing features.
  * Deprecated --clear-target-pool flag from compute instance-groups managed
    set-target-pools command.
  [#]## Windows support
  * Windows Installer can now take a /logtofile flag to write installation
    logs to file CloudSDKInstall.log located in the same directory.
  * Windows installer now displays an error message when the installation
    does not succeed.
  [#]## Command Line Interface support
  * The [page=N] table format attribute prints one or more tables of at
    most N rows. Use this to view paged server data as it arrives at
    the client.
  * From 0.9.83 (2015/10/21)
  [#]## App Engine
  * In a future release, the `gcloud preview app deploy` command will
    no longer support deploying multiple modules in the same invocation.
  [#]## Compute
  * Ubuntu 14.10 is end of life: https://wiki.ubuntu.com/Releases
  * Fixed external issue [#291]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=291),
    related to handling network addresses on Windows.
  [#]## Container Engine
  * `gcloud container clusters list` now displays the current number of nodes
    for the cluster.
  [#]## Windows support
  * When running Cloud SDK tools from PowerShell the `gcloud-ps.ps1` wrapper
    scripts now can be used which no longer call to `cmd.exe`. Using
    `gcloud-ps`, complex arguments can be passed without escaping for
    Windows command line. Using `gcloud`, the following command would be
    correctly escaped when running gcloud in PowerShell:
    gcloud fun --arg='"test ^< 123"'
    With the new `gcloud-ps`, the same command can be simply written as:
    gcloud-ps fun --arg='test < 123'
    Permissions to run PowerShell scripts must be given to PowerShell
    before these will work. Permissions can be changed with
    `"Set-ExecutionPolicy RemoteSigned"`.
  * From 0.9.82 (2015/10/14)
  [#]## App Engine
  * The App Engine Admin API is now the default path for deployments in the
    `gcloud preview app deploy` command. This transition should be
    transparent, but if you experience any issues and would like to
    revert to the old behavior, please run `gcloud config set
    app/use_appengine_api false`.
    See <https://cloud.google.com/appengine/docs/admin-api/> for more
    information about this API.
  * With `env: 2`, valid python runtimes are `python` and `python-compat`.
  * Implemented fingerprinting support for python.
  [#]## Container Engine
  * `gcloud container clusters create`: The flag `--container-ipv4-cidr` has
    been deprecated; `--cluster-ipv4-cidr` should be used instead.
  [#]## SQL
  * `gcloud beta sql operations describe` and
    `gcloud beta sql operations wait` no longer need `--instance`
    flag (`gcloud beta sql operations list` still does).
  * Fixed issue with `gcloud sql instances clone` when `--bin-log-file-name`
    and `--bin-log-position` are set.
    (<https://code.google.com/p/google-cloud-sdk/issues/detail?id=201>).
  * From 0.9.81 (2015/10/07)
  [#]## Breaking Changes
  * If you are using a service account to run commands under
    `gcloud preview app`, you must enable the "App Engine Admin API" in the
    Developers Console (<https://console.developers.google.com>; navigate to
  * *APIs and Auth > APIs**).
  * In a future Cloud SDK release, deployments that promote the new version to
    receive all traffic will stop the previous version by default.
    To keep the current behavior, pass the `--no-stop-previous-version`
    flag, or run the following command:
    $ gcloud config set app/stop_previous_version false
  * Removed `app get-resource-limits` command.
  [#]## App Engine
  * App Engine components updated to 1.9.27. Please see the following release
    notes for details:
  * Python: <https://cloud.google.com/appengine/docs/python/release-notes>
  * Java: <https://cloud.google.com/appengine/docs/java/release-notes>
  * The `gcloud preview app deploy` command now requires that users specify or
    omit the runtime: field from app.yaml if a Dockerfile is also specified.
  * The `gcloud preview app deploy` command now supports the "engines" field
    in package.json for node.js applications.
  [#]## Misc. Changes
  * Windows Installer has an option to run `gcloud init` after the
    installation finishes.
  * From 0.9.80 (2015/09/30)
  * `gcloud app`
  * Soon, deployments will set the deployed version to receive all traffic
    by default.  To keep the current behavior, use the `--no-promote` flag
    or run the following command:
    $ gcloud config set app/promote_by_default false
    To adopt the new behavior early, use the `--promote` flag or run the
    following command:
    $ gcloud config set app/promote_by_default true
  * The `--set-default` flag is deprecated. Please use the `--promote` flag
    instead.
  * In a future Cloud SDK release, deployments that promote the new version
    to receive all traffic will stop the previous version by default.  To
    keep the current behavior, pass the `--no-stop-previous-version` flag,
    or run the following command:
    $ gcloud config set app/stop_previous_version true
  * The `app run` command is deprecated and will soon be removed.  Please
    use dev_appserver (found in the same directory as the `gcloud command)
    instead.
  * The `gcloud preview app modules download command` is deprecated, and
    will be removed soon.
  * The Windows installer has an option to run `gcloud init` after the
    installation finishes.
  * The `preview` component has been removed.
  * The `gcloud preview app` commands remain available as usual and
    are still shipped through the `app` component.
  * Please use `gcloud compute instance-groups unmanaged` instead
    of `gcloud preview instance-groups`.  Note that you will need to
    modify some command invocations when switching to the non-preview
    commands.
  * Please use `gcloud compute instance-groups managed` instead of
    `gcloud preview managed-instance-groups`.  Note that you will need to
    modify some command invocations when switching to the non-preview
    commands.
  * All Google Compute User Accounts commands have moved to beta.
  * Deployment-manager list commands now support pagination.
  * Minor bug fixes.
  * From 0.9.79 (2015/09/23)
  * The following commands have been promoted from beta to GA:
  * gcloud config configurations ...
  * gcloud source repos clone
  * gcloud beta init. Old `gcloud init` behavior has been removed, and
    partially replaced by new gcloud init or directly via gcloud source
    repos clone.
  * Release gcloud beta dataproc.
  * The --env-vars flag in gcloud preview app deploy has been removed.
  * Automatic ssh key generation respects the --quiet flag.
  * The --format flag now supports extended format expressions. For
    details run
    $ gcloud topic formats.
  * Most commands now document the positive Boolean --FLAG form and accept
  - -no-FLAG to disable. For the past few releases --log-http accepted an
    optional true/false value. It has been restored to its original definition
    of being a Boolean flag that has no value.
  * `gcloud sql` operations are now automatically retried for 2s in case of
    HttpException: The Cloud SQL instance operation does not exist.
  * Update gcloud's kubectl from 1.0.5 to 1.0.6.
  * Deprecate `gcloud preview app get-resource-limits`.
  * From 0.9.78 (2015/09/16)
  * App Engine components updated to 1.9.26. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
  * Increase the default boot disk size for remote build VMs in
    `gcloud preview app deploy`.
  * The `--instance` flag to the `gcloud preview app modules set-managed-by`
    command now takes an instance name instead of an index.
  * The V1Beta4 API for sqladmin can now be accessed through the
    `gcloud beta sql` surface.
  * Usability enhancements for `gcloud beta init` and named configurations.
  * From 0.9.77 (2015/09/09)
  * gcloud preview logging is now gcloud beta logging.
  * Update kubectl to version 1.0.5
  * Windows Cloud SDK installer improvements:
  * Now allows changing the installation mode. You can choose between a
    "current user" installation and an "all users" installation.
  * Now has an uninstaller and writes "Add/Remove Programs" uninstall
    entries.
  * Removal of unsupported --env-vars argument from gcloud preview app deploy.
  * gcloud compute instance groups: Allow --named-ports flag to be empty and
    clean named ports in set-named-ports commands.
  * Change in gcloud compute backend-services: introduce new flag
  - -instance-group which takes advantage of new Instance Groups API.
  * From 0.9.76 (2015/09/02)
  * Update gsutil component to 4.14.
  * Resource views commands have moved from preview to alpha. Please
    use `gcloud alpha compute resource-views` in place of
    `gcloud preview resource-views`.
  * Replica pool commands have moved from preview to alpha. Please use
    `gcloud alpha compute replica-pools` in place of
    `gcloud preview replica-pools`.
  * `gcloud beta source repo` was renamed to `gcloud beta source repos`
  * Created google-cloud-sdk-announce@googlegroups.com
    <https://groups.google.com/d/forum/google-cloud-sdk-announce> email
    group to announce new releases and other important information.
  * 'gcloud alpha init' command is now also in beta.
  * Add target size of managed instance group for "compute instance-groups
    managed list" command.
  * Fixed the removal of platform-specific components when running `gcloud
    components remove`.
  * Fixed a bug related to checking for SDK updates when the SDK is
    installed as root (like on Debian Compute Engine images).
  * Affected users should now see less frequent update messages and overall
    improved gcloud performance
  * `gcloud preview app deploy` won't update local images automatically
    anymore.
  * From 0.9.75 (2015/08/26)
  * Container Engine
  * Container Engine GA commands available under `gcloud container`.
  * `gcloud beta container get-credentials` now takes cluster name as
    argument instead of `--cluster` flag for consistency with other
    commands.
  * Added `gcloud alpha container clusters update <cluster>
  - -cloud-monitoring=<val>` command.
  * New release notes are printed on upgrade. (This won't take effect until
    an upgrade from this version to a later version.)
  * New `gcloud alpha genomics variantsets export` command.
  * Commands promoted from `gcloud alpha` to `gcloud beta`:
  * `gcloud beta config configurations ...`
  * `gcloud beta sources clone`
  * Improvements in error reporting and default output formatting.
  * From 0.9.74 (2015/08/19)
  * New list and import commands under `gcloud alpha genomics variants`.
  * Removed `--remote` flag. Instead, please use the `--docker-build=remote`
    flag (or use `--docker-build=local` to force a local build).
  * In this release, Docker builds are hosted by default. To opt-in to
    the old behavior, please use the `--docker-build=local` flag.
  * 0.9.73 (2015/08/12)
  * gcloud sql instances create default to MySQL 5.6
  * gcloud beta container get-credentials renamed to gcloud beta container
    clusters get-credentials
  * New commands
  * gcloud beta projects ...
  * gcloud alpha genomics callsets ...
  * gcloud beta emulators datastore ...
  * gcloud beta container get-server-config
  * gcloud alpha config configurations
  * From 0.9.72 (2015/08/05)
  * gcloud compute
  * initial surface changes for the backend-bucket.
  * `instance-groups set-named-ports`: introduced a new flag
    `--named-ports NAME:PORT,[NAME:PORT,...]` - no need to specify names
    and ports in separate flags.
  * gcloud preview app deploy
    Deprecate `--remote` flag in preparation for hosted Docker builds by
    default. Instead, please use the `--docker-build={remote,local}` flag.
    The default is still a local Docker build; in two releases, the default
    will switch to a hosted build.
  * New gcloud alpha genomics operations {list, cancel, describe} commands
  * From 0.9.71 (2015/07/29)
  * Launching `gcloud alpha pubsub` commands.
  * Moved `gcloud preview rolling-updates` to
    `gcloud alpha compute rolling-updates`.
  * `gcloud alpha compute disks resize` command enabling resizing of
    persistent disks.
  * Beta launch of customer supplied encryption keys for Compute Engine.
  * Updated kubectl to 1.0.1.
  * `gcloud alpha container` commands now target Container Engine v1 API.
    Options for `gcloud alpha container clusters create` updated accordingly:
  * `--user` renamed to `--username`
  * `--cluster-api-version` removed. Cluster version is not selectable in
    v1 API; new clusters always created at latest supported version.
  * `--image` option removed. Source image not selectable in v1 API;
    clusters are always created with latest supported ContainerVM image.
    Note that using an unsupported image (i.e. not ContainerVM) would
    result in an unusable cluster in most cases anyway.
  * Added `--no-enable-cloud-monitoring` to turn off cloud monitoring
    (on by default).
  * Added `--disk-size` option for specifying boot disk size of node vms.
  * App Engine components updated to 1.9.24. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
    For several months on the Managed VMs team we've been testing a new
    mode of `dockerless` local development on gcloud that makes developing
    a module for Python, Java and Go users similar to development of
    regular App Engine applications. This new mode relaxes the sandbox
    constraints present in the devappserver for `vm: false` applications,
    and does not require Docker to be installed.
    You can currently opt-into this behavior by setting
    GAE_LOCAL_VM_RUNTIME=1; In this release of the Cloud SDK, we will be
    making this behavior the default for Managed VM users who are using
    gcloud.
    You can still opt-out of this behavior by setting: GAE_LOCAL_VM_RUNTIME=0.
    For custom runtime users, if you are relying on the local Development
    Server to build your application, will now need to pass the
    `--custom-entrypoint` flag to `gcloud preview app run` to provide
    gcloud with the correct command to call.
    This does not affect users developing for non-managed VMs, or for
    users who are not using gcloud."
  * Bug fixes for:
  * `gcloud preview app deploy` file paths issue on Windows.
  * `gcloud compute instance-groups managed wait-until-stable` periodic user
    prompting for target zone.
  * From 0.9.70 (2015/07/22)
  * Add `gcloud compute instance-groups` commands.
  * Move `gcloud beta deployment-manager` commands to general availability as
    `gcloud deployment-manager` and update to use the v2beta3 API. This change
    does not alter the gcloud surface for users of the deployment-manager
    component.
  * Update kubectl to 1.0.0.
  * `gcloud alpha genomics` commands now use the genomics V1 API. The
  - -project-number flag for `dataset create` and `dataset list` is now
    obsolete. The configured --project-id is used instead and can be
    overridden with the --project-id flag.
  * Fix hang on errors in `gcloud preview app deploy`.
  * From 0.9.69 (2015/07/15)
  * Update kubectl to 0.20.2.
  * Fix an authentication issue with 'gcloud docker' affecting docker version
    1.7.0 and later.
  * Remove `gcloud preview dm-v2` command group.
  * Remove `gcloud preview deployment-manager` command group
    (`gcloud beta deployment-manager` still exists; see
    <https://cloud.google.com/sdk/#install-version> if you want to pin your
    installation to an old version).
  * Bug fixes.
  * From 0.9.68 (2015/07/08)
  * Deprecated gcutil tool is no longer distributed with Cloud SDK.
    It is still available via <https://cloud.google.com/compute/docs/gcutil>.
  * Added support for Container engine BETA commands under the
    `gcloud beta container` command group.  Existing `gcloud alpha container`
    commands are unchanged.
  * The standalone App Engine SDKs are no longer distributed through the
    Cloud SDK.
  * App Engine functionality can still be used through the
    `gcloud preview app` command group.
  * The gae-java, gae-python, gae-php, and gae-go components no longer
    exist in the component manager.
  * If you need to use appcfg or dev_appserver directly, these are still
    available in the App Engine SDK downloads that can be found here:
    <https://cloud.google.com/appengine/downloads>
  * Bug fixes.
  * From 0.9.67 (2015/07/01)
  * App Engine components updated to 1.9.23. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
  * Added the "gen-config" command to app surface to generate configuration
    files for node.js apps.
  * New `compute instance-groups unmanaged` commands group for Instance
    Groups which are not managed by Instance Group Manager
  * Moved `gcloud beta sql instances connect` to `gcloud beta sql connect`.
  * Smarter polling while waiting for SQL operations to finish, reducing the
    number of requests sent to the server.
  * Linux/Mac install script disables prompts if there is no controlling tty.
  * Linux/Mac install script now properly detects zsh and ksh RC files.
  * Bug fixes.
  * From 0.9.66 (2015/06/24)
  * New commands
  * `gcloud alpha compute instances set-machine-type` for managing types
  * `gcloud topic` for supplementary help topics.
  * `gcloud deployment-manager deployments delete` prompt defaults to false.
  * From 0.9.65 (2015/06/17)
  * Fixes `reset-windows-password` on Windows if `openssl` is present on the
    path.
  * `gcloud compute reset-windows-password` is now available as a GA command.
  * Prevent creation of a user that matches the machine name on Windows.
  * gsutil now runs properly from not-default drive letters on Windows.
  * kubectl updated to 0.18.1.
  * `gcloud preview docker` moved to `gcloud docker`.
  * From 0.9.64 (2015/06/10)
  * New commands
  * `gcloud beta compute scp` for secure copy.
  * `gcloud alpha genomics` commands (on datasets).
  * `gcloud alpha source list` to lists project repositories.
  * kubectl will no longer be installed by default.
  * Bug fixes for https load balancing.
  * The help pager is $PAGER or less(1) if available, otherwise a
    builtin pager.
  * Update of gsutil component to version 4.13.
  * From 0.9.63 (2015/06/03)
  * 2x faster command load times.
  * Fix to allow `preview app` to use oauth service accounts
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=133>
  * From 0.9.62 (2015/05/27)
  * Not released.
  * From 0.9.61 (2015/05/20)
  * New kubectl component (installed by default)
  * Internal improvements to gcloud preview app deploy; includes changes to
    command output.
  * `gcloud preview projects` moved to `gcloud alpha projects`
  * Tab completion for `gcloud compute ssh`
  * From 0.9.60 (2015/05/13)
  * VPN moved to GA.
  * Preemptible VM support.
  * Bug fixes.
  * From 0.9.59 (2015/05/06)
  * Bug fixes.
  * From 0.9.58 (2015/04/29)
  * gcloud alpha bigquery launch.
  * Better error reporting in Customer Supplied Encryption Key files.
  * Bug fixes.
  * From 0.9.57 (2015/04/22)
  * gcloud beta deployment-manager launch.
  * gcloud app new deployment behavior.
  * deploy and run commands no longer take directories, only take a list of
    explicit yaml files.
  * gcloud beta compute reset-windows-password, support for new authentication
    scheme on Windows guest agent versions 3.0.0.0 and later.
  * Bug fixes.
  * From 0.9.56 (2015/04/15)
  * Bug fixes.
  * from 0.9.55 (2015/04/8)
  * New and improved gcloud dns surface including:
  * Transactions for scriptable editing of record-sets.
  * Importing record-sets from zone files and yaml files.
  * Exporting record-sets to zone files and yaml files.
  * VPN commands surfaced under gcloud compute.
  * Dataflow CLI commands launched under gcloud alpha!
  * From 0.9.52 (2015/03/18)
  * Bug Fixes.
  * From 0.9.51 (2015/03/11)
  * Bug Fixes.
  * From 0.9.50 (2015/03/04)
  * Introducing the `gcloud beta ...` command group
  * Existing gcloud commands will be replicated under this new group, but
    use the beta version of their API instead of the GA version.
  * New command behavior and features that are beta only will first appear
    under this group until the feature gets promoted to general
    availability.
  * Run `gcloud components update beta` to access the new commands, or it
    will be automatically installed for you on first run attempt.
  * `gcloud beta compute ...` is now available, using the compute 'beta' API.
    Cloud VPN.  See <https://cloud.google.com/compute/docs/vpn>
    for details.
  * Release of `gcloud compute instances move` and
    `gcloud compute disks move`.
  * From 0.9.49 (2015/02/25)
  * The Google Container Registry is now used by default for deployment of
    Managed VM applications. See here for more information:
    <https://cloud.google.com/tools/container-registry/>
  * We've increased the speed of the "image push" phase of Managed VM
    deployments.
  * The heavy lifting of retrieving the Go toolchain has been moved into the
    base Go Docker image which dramatically reduces the bandwidth consumed
    locally when running and deploying your images. You must delete your
    Dockerfile to pick up the changes.
  * We've fixed several bugs related to port forwarding in the local
    devappserver.
  * From 0.9.48 (2015/02/18)
  * A bug fix for running setup-managed-vms multiple times when using
    the Google Container Registry
  * From 0.9.47 (2015/02/11)
  * Bug fixes that allow tab completion to work for components in preview.
  * GCloud now auto installs components based on command execution.
  * From 0.9.46 (2015/02/04)
  * We've made significant improvements to the stability and speed of
    deploying Managed VMs by leveraging the new Google Container Registry.
    See this post for details on how to try it out today:
    <https://groups.google.com/forum/#!topic/google-appengine/c543NHZGhKM>
  * From 0.9.45 (2015/01/28)
  * Several bug fixes in the Dockerfile generated for the 'go' runtime.
    Delete the Dockerfile in your application directory and the Cloud SDK
    will copy the updated Dockerfile on your next deployment.
  * Several bug fixes related to flakiness in the setup-managed-vms command.
* Sat Jan 31 2015 rjschwei@suse.com
- Add patches:
    + gsutil_noVersioCheckOrUpdate.patch
    + gsutil_respectBotoCfgKeyword.patch
    + hidePathMangeling.patch
  Remove patches:
  - gcloudFixPath.patch
  - gsutilSupportBotoCfgKeyword.patch
- Update to version 0.9.44   bnc#915479
  + Fixes applied to the google/appengine-gobase image for managed VMs.
  + Tab completion for gcloud SQL commands.
  + Support added for authenticating service accounts with JSON keys.
    If using JSON keys, PyOpenSSL is no longer a dependency.
  + Suport for local ssds in instance templates for gcloud compute.
  + Progress Bars.
  + Compute Instances start/ stop commands.
  + Bug Fixes.
  + Added support for local SSD.
  + Added support for Google Compute Engine Instance Templates in
    compute component.
  + Overhaul of 'gcloud sql'
    ~ Updated the output for all commands.
    ~ Updated usage for 'gcloud sql ssl-certs create'.
  + Added support for creating and maintaining Cloud SQL read replica instances.
    ~ Added --master-instance-name property that can be set during replica
    creation to indicate the replication master for the read replica instance.
    ~ Added --enable-database-replication, --no-enable-database-replication
    flags that can be used to start, stop replication for the read replica
    instance.
    ~ Added 'promote-replica' command that promotes a read replica instance into
    a stand-alone Cloud SQL instance.
  + Added several new features to the compute component:
    ~ Implemented new subcommands for interacting with HTTP load balancing:
  - gcloud compute url-maps add-host-rule
  - gcloud compute url-maps add-path-matcher
  - gcloud compute url-maps remove-host-rule
  - gcloud compute url-maps remove-path-matcher
  - gcloud compute url-maps set-default-service
    ~ Added support for automatically generating initial Windows username and
    password when creating a virtual machine instance from a Windows
    image or a disk initializaed from a Windows image.
    ~ Added a new scope alias for Cloud SQL administration: 'sql-admin'.
  + The compute component is now in General Availability.
    ~ Added new 'compute/zone' and 'compute/region' properties that
    can be used to set a default zone and region. To set the
    properties, run 'gcloud config set compute/zone ZONE' and 'gcloud
    config set compute/region REGION'.
    ~ Added support for overriding disk auto-deletion during instance
    deletion.
    ~ Updated the output of commands that mutate resources to be more
    human-friendly. The --format flag can be used for more verbose
    output.
    ~ Replaced all 'get' subcommands with 'describe' subcommands (e.g.,
    'gcloud compute instances get' has been replaced with 'gcloud
    compute instances describe').
    ~ Renamed the 'firewalls' collection to 'firewall-rules'.
    ~ Added support to the 'addresses' collection for interacting with
    global addresses.
  + Updated gcutil to 1.16.3 and various AppEngine runtimes to 1.9.7 binaries.
  + Support running several modules by gcloud app run and fixed output errors.
  + Limit gcloud upgrade nags to once per day.
  + Bring help files up to date (for example improved the documentation
    for DM 'templates create' and 'deployments create').
  + Added prompting for regions and zones to most subcommands of the
    compute component.
  + Added new subcommands to the compute component for adding and removing
    backends from backend services.
  + Added --ssh-flags to 'gcloud compute ssh' for passing additional flags
    to ssh.
  + Added image alias support for the --image flag in the compute component.
  + Added --shell mode to all gcloud commands
    ~ Type a partial command followed by '--shell' to drop into a sub shell
    at that point in the command tree.
    ~ Eg:
    $ gcloud compute --shell
    gcloud compute $ instances list
    gcloud compute $ copy-files ...
  + Updated gsutil to 4.3
  + Allow installed crcmod to be used by default with gsutil by enabling
    site packages
* Fri Jun 27 2014 rschweikert@suse.com
- Disable the Google built in "component" management and version upgrade
  mechanism
  + add hideImplicitVersionMgmt.patch
* Sat Jun 21 2014 rschweikert@suse.com
- Fix setup file to properly include package data embedded in
  googlecloudsdk package, previously *.json files were missing
* Tue Jun 17 2014 rschweikert@suse.com
- Remove debug print from setup.py
- Include templated html files as data files, these are used by the
  auth setup workflow
* Fri Jun  6 2014 rschweikert@suse.com
- Remove unnecessary dependency on python-oauth2
* Thu Jun  5 2014 rschweikert@suse.com
- Update to version 0.9.25
  + 'gcloud preview app deploy' and '... run' argument updates.
  + 'gcloud config *' argument updates.
  + Updated all AppEngine tools to 1.9.5
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + gcloud now has App Engine and Cloud Datastore integration.
  - Commands can be found under `gcloud preview app` and
    `gcloud preview datastore`
  + New `gcloud compute` tool for working with compute engine (RC)
  - Run `gcloud components update compute` to install
  - Run `gcloud help compute` for more information
  + Updated all AppEngine tools to 1.9.4
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + Added color to error and warning messages (on Linux and Mac)
  - To disable, run `gcloud config set disable_color true`
  + New 'gcloud help command'
  - Displays man style extended help for commands (where available).
  + New 'gcloud auth activate-service-account' command
  - Used to authenticate with gcloud using a service account key file.
  - See: https://developers.google.com/storage/docs/authentication#service_accounts
- Enable "big query" install and use
  + add patch bqHideDeps.patch
- Fix use of gcloud command
  + add patch gcloudFixPath.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Update to version 0.9.18
  + Updated all AppEngine tools to 1.9.0
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + New 'gcloud init' command
  - Creates a local workspace for your project with a git clone of
    your Google hosted repository.
  + Updated gcutil to 1.14.0
  - Switched to new, single API call for creating a virtual machine instance
    with a root persistent disk.
  - Added new command, 'setinstancediskautodelete', that sets the
    auto-delete option for persistent disks attached to virtual
    machine instances.
  - Added support for specifying a disk size when creating a disk using
    a snapshot.
  - Decreased the time spent waiting for SSH keys to propagate
    during initial instance creation from 120 seconds to 10 seconds.
* Thu Mar  6 2014 rschweikert@suse.com
- Disable gcutil internal version check
- add patch: gcutilNoInternalVersionCheck.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Support the new boto config option and recognize the "system"
  keyword. Set the certificates file to None to use the system
  implementation
- add patch: gsutilSupportBotoCfgKeyword.patch
* Thu Feb 27 2014 rschweikert@suse.com
- Add missing dependency to python-setuptools
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Wed Feb 26 2014 rschweikert@suse.com
- Add missing package dependencies
* Wed Feb 26 2014 rschweikert@suse.com
- Remove the dependency on python-oauth2, this is only needed when using
  the oauth2client delivered with the sdk tarball. However, we use the
  already packaged version of the client google-api-python-client which
  does not have that dependency. Thus the dependency is superfluos.
* Mon Feb 24 2014 rschweikert@suse.com
- Fix the gcutilHideDeps.patch to hide requirements on python versions < 2.7
  this fixes build on SLE 11
* Mon Feb 24 2014 rschweikert@suse.com
- Use the setup.py code of the "integrated" gsutil and gcutil code
  the toplevel gsutil and gcutil commands are useless wrappers that play
  extremely stupid tricks with the path and other stuff.
- Add patch gsutilHideDeps.patch and gcutilHideDeps.patch to hide the
  hard dependencies for gsutil and gcutil, respectively
* Thu Feb 20 2014 rschweikert@suse.com
- Adjust version settings for obsoletes and provides
* Wed Feb 19 2014 rschweikert@suse.com
- Initial build
